@@ -1,6 +1,16 @@
 """Analog - Log Analysis Utitliy."""
 from __future__ import (absolute_import, division, print_function,
                         unicode_literals)
+import logging
+
+
+__version__ = '0.3.2'
+
+
+# analog logger
+LOG = logging.getLogger('analog')
+LOG.addHandler(logging.NullHandler)
+
 
 from analog.analyzer import Analyzer, analyze
 from analog.exceptions import (AnalogError, InvalidFormatExpressionError,
@@ -11,9 +21,6 @@ from analog.report import Report
 from analog.renderers import Renderer
 
 
-__version__ = '0.3.0'
-
-
 __all__ = (
     __version__,
     AnalogError,
